@@ -2,22 +2,12 @@
 
 # python stdlib
 import sys
-import logging
 
+# 3rd party imports
+from ruamel import yaml  # NOQA: F401
 
-log = logging.getLogger(__name__)
-
-
-try:
-    from ruamel import yaml
-except ImportError:
-    try:
-        import yaml
-    except ImportError:
-        log.critical("Unable to import either ruamel.yaml or pyyaml")
-        sys.exit(1)
-
-log.debug("Using yaml library: {0}".format(yaml.__file__))
+# Build our global yml object that will be used in all other operations in the code
+yml = yaml.YAML(typ='safe', pure=True)
 
 
 if sys.version_info[0] < 3:
